@@ -47,7 +47,13 @@ def getDynamicDomain():
 @app.command()
 def install(
     domain: str = typer.Option(
-        getDynamicDomain(), "--domain", "-d", help="Backplane Domain"
+        getDynamicDomain(), "--domain", "-d", help="The domain your backplane runs on"
+    ),
+    mail: str = typer.Option(
+        "",
+        "--mail",
+        "-m",
+        help="The mail address used for LetsEncrypt",
     ),
 ):
     error = False
@@ -171,41 +177,41 @@ def install(
             typer.secho("default config does not exist", err=True, fg=typer.colors.RED)
 
         if backplane["environment"] == "development":
-            try:
-                subprocess.run(
-                    ["cp", ".env.example", ".env"],
-                    cwd=backplane["default_context_dir"],
-                )
-                if backplane["verbosity"] > 0:
-                    typer.secho(
-                        "Successfully created default config",
-                        err=False,
-                        fg=typer.colors.GREEN,
-                    )
+            domain = "127-0-0-1.nip.io"
+            # try:
+            #     subprocess.run(
+            #         ["cp", ".env.example", ".env"],
+            #         cwd=backplane["default_context_dir"],
+            #     )
+            #     if backplane["verbosity"] > 0:
+            #         typer.secho(
+            #             "Successfully created default config",
+            #             err=False,
+            #             fg=typer.colors.GREEN,
+            #         )
 
-            except Exception as e:
-                error = True
-                typer.secho(
-                    f"Failed to create default config: {e}",
-                    err=True,
-                    fg=typer.colors.RED,
+            # except Exception as e:
+            #     error = True
+            #     typer.secho(
+            #         f"Failed to create default config: {e}",
+            #         err=True,
+            #         fg=typer.colors.RED,
+            #     )
+            #     raise typer.Exit(code=1)
+        try:
+            with open(f"{backplane['default_context_dir']}/.env", "w") as writer:
+                writer.write(
+                    f"BACKPLANE_DOMAIN={domain}\nBACKPLANE_ENVIRONMENT={backplane['environment']}\nBACKPLANE_MAIL={mail}"
                 )
-                raise typer.Exit(code=1)
-        else:
-            try:
-                with open(f"{backplane['default_context_dir']}/.env", "w") as writer:
-                    writer.write(
-                        f"BACKPLANE_DOMAIN={domain}\nBACKPLANE_ENVIRONMENT=production\n"
-                    )
 
-            except Exception as e:
-                error = True
-                typer.secho(
-                    f"Failed to create default config: {e}",
-                    err=True,
-                    fg=typer.colors.RED,
-                )
-                raise typer.Exit(code=1)
+        except Exception as e:
+            error = True
+            typer.secho(
+                f"Failed to create default config: {e}",
+                err=True,
+                fg=typer.colors.RED,
+            )
+            raise typer.Exit(code=1)
     else:
         if backplane["verbosity"] > 0:
             typer.secho("default config exists", err=False, fg=typer.colors.GREEN)
@@ -292,6 +298,8 @@ def uninstall(
                 if network.attrs["Labels"]["provider"] == "backplane":
                     network.remove()
 
+    typer.secho("Successfully uninstalled backplane", err=False, fg=typer.colors.GREEN)
+
 
 @app.command()
 def update():
@@ -631,8 +639,10 @@ def checkPrerequisites(ctx):
         typer.secho("git not installed", err=True, fg=typer.colors.RED)
         sys.exit(1)
 
-    if not os.path.exists(backplane["active_context_dir"]):
-        if ctx.invoked_subcommand not in ["install", "uninstall"]:
+    if not os.path.exists(backplane["config_dir"]):
+        if ctx.invoked_subcommand == "install":
+            pass
+        else:
             typer.secho(
                 "config directory missing. Run 'backplane install' first.",
                 err=True,
@@ -640,6 +650,17 @@ def checkPrerequisites(ctx):
             )
             sys.exit(1)
 
+    if not os.path.exists(backplane["active_context_dir"]):
+        if ctx.invoked_subcommand == "install":
+            pass
+        else:
+            typer.secho(
+                "active context directory missing. Run 'backplane install' first.",
+                err=True,
+                fg=typer.colors.RED,
+            )
+            sys.exit(1)
+
 
 @app.callback()
 def callback(
@@ -652,11 +673,19 @@ def callback(
         None, "--version", callback=version_callback, is_eager=True
     ),
 ):
+
     backplane["verbosity"] = verbosity
-    backplane["environment"] = os.getenv("BACKPLANE_ENVIRONMENT", environment)
+
     backplane["config_dir"] = os.getenv(
         "BACKPLANE_CONIG_DIR", os.path.join(os.getenv("HOME", "~"), ".backplane")
     )
+
+    load_dotenv(dotenv_path=backplane["config_dir"])
+
+    backplane["environment"] = os.getenv("BACKPLANE_ENVIRONMENT", environment)
+
+    print(backplane["environment"])
+
     backplane["active_context"] = os.getenv("backplane['active_context']", "default")
     backplane["contexts_dir"] = os.getenv(
         "BACKPLANE_CONTEXTS_DIR", os.path.join(backplane["config_dir"], "contexts")
